import React, { useState, useEffect } from 'react';
import { Modal, Form, Input, DatePicker, Checkbox, Button, Select, InputNumber, message } from 'antd';
import moment from 'moment';
import { getGoods } from '../services';

const RuleForm = (props) => {
    const { RangePicker } = DatePicker;
    const [checked, setChecked] = useState(false);
    const [dateDisable, setDateDisable] = useState(false);
    const [itemDisable, setItemDisable] = useState(false);

    useEffect(() => {
        const ruleAts = [];
        if (props.values) {
            if (props.values.startAt) {
                props.values.startAt = moment(props.values.startAt);
            }
            ruleAts.push(props.values.startAt);
            if (props.values.endAt) {
                props.values.endAt = moment(props.values.endAt);
            }
            ruleAts.push(props.values.endAt);
            props.values.ruleAt = ruleAts;
        }
        if (props.values.ruleType == 2) {
            setItemDisable(true);
            setDateDisable(true);
            if (props.values.isLong == 1) {
                setChecked(true);
            } else {
                setChecked(false);
            }
        } else {
            setItemDisable(false);
            setDateDisable(false);
            if (props.values.isLong == 1) {
                setChecked(true);
                setDateDisable(true);
            } else {
                setChecked(false);
                setDateDisable(false);
            }
        }
    }, [props.values]);

    const CheckboxChange = (e) => {
        if (e.target.checked) {
            setChecked(true);
            setDateDisable(true);
        }
        else {
            setChecked(false);
            setDateDisable(false);
        }
    }

    const ruleTypeChange = (value) => {
        if (value == 1) {
            setItemDisable(false);
            if (checked) {
                setDateDisable(true);
            } else {
                setDateDisable(false);
            }
        } else {
            setItemDisable(true);
            setDateDisable(true);
        }
    }

    return (
        <Modal
            title={'编辑销售规则'}
            width={640}
            visible={props.ruleModelVisible}
            bodyStyle={{ padding: '32px 40px 48px' }}
            footer={null}
            onCancel={() => {
                props.onCancel();
            }}
            destroyOnClose
        >
            <Form
                layout="Horizontal"
                initialValues={props.values}
                onFinish={props.onFinish}
            >
                <Form.Item name="id" hidden={true}>
                    <Input />
                </Form.Item>
                <Form.Item name="ruleType" label="规则类型" rules={[{ required: true }]}>
                    <Select style={{ width: '100%' }} onChange={ruleTypeChange}>
                        <Select.Option value={1}>时间范围</Select.Option>
                        <Select.Option value={2}>每日</Select.Option>
                    </Select>
                </Form.Item>
                <Form.Item name="ruleAt" label="销售时间" style={{ marginLeft: '10px' }}>
                    <RangePicker showTime format="YYYY-MM-DD HH:mm:ss" style={{ width: '100%' }} disabled={dateDisable} />
                </Form.Item>
                <Form.Item name="isLong" valuePropName="checked" label="是否长期有效" style={{ marginLeft: '10px' }}>
                    <Checkbox style={{ marginLeft: '10px' }} onChange={CheckboxChange} disabled={itemDisable} checked={checked}></Checkbox>
                </Form.Item>
                <Form.Item name="saleCount" label="销售数量" rules={[{ required: true }]}>
                    <InputNumber style={{ width: '100%' }} min={0} />
                </Form.Item>
                <Form.Item style={{ marginLeft: '10px' }}>
                    <Button type="primary" htmlType="submit">
                        保存
                    </Button>
                </Form.Item>
            </Form>
        </Modal>
    )
};

export default RuleForm;